#
# spec file for package icewm
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global lites icewm icewmhint icewmbg icesh icewm-session
Name:           icewm
Version:        3.7.3
Release:        1.1
Summary:        Window Manager with a Taskbar
License:        LGPL-2.1-or-later
Group:          System/GUI/Other
URL:            https://ice-wm.org/
Source0:        https://github.com/ice-wm/%{name}/releases/download/%{version}/%{name}-%{version}.tar.lz
# PATCH-FEATURE-SUSE icewm-susemenu.patch tyang@suse.com -- Add xdg-menu for SLED icewm
Patch1:         icewm-susemenu.patch
# PATCH-FIX-OPENSUSE icewm-desktop-nodisplay.patch qkzhu@suse.com -- Set NoDisplay for icewm.desktop
Patch2:         icewm-desktop-nodisplay.patch
Patch99:        icewm-preferences.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  gettext-runtime >= 0.21.0
BuildRequires:  libtool
BuildRequires:  lzip
BuildRequires:  pkgconfig
BuildRequires:  update-alternatives
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(fribidi)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(ice)
BuildRequires:  pkgconfig(imlib2)
BuildRequires:  pkgconfig(librsvg-2.0)
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(sndfile)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xcomposite)
BuildRequires:  pkgconfig(xdamage)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xfixes)
BuildRequires:  pkgconfig(xft)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xpm)
BuildRequires:  pkgconfig(xrandr)
Requires:       alsa-utils
Requires:       desktop-data
Requires:       icewm-bin
Requires:       imlib2-loaders
Requires:       xdg-menu
Requires(post): update-alternatives
Requires(postun): update-alternatives
# If you have the choice, prefer the big one.
Recommends:     icewm-default
Recommends:     xclock
# For locking you need xscreensaver
Recommends:     xscreensaver
Provides:       icewm-gnome = %{version}
Obsoletes:      icewm-gnome < %{version}
Provides:       windowmanager
# Needed for documentation.
%if 0%{?suse_version} <= 1320
BuildRequires:  asciidoc
%else
BuildRequires:  rubygem(asciidoctor)
%endif
%if !0%{?sle_version}
Requires:       icewm-configuration-files
%else
Requires:       icewm-theme-branding
%endif
%if 0%{?sle_version}
Recommends:     polkit-gnome
%endif
%if 0%{?suse_version} > 1315
Requires:       xterm-bin
%else
Requires:       xterm
%endif

%description
A window manager for the X Window System that can emulate the look
of Windows '95, OS/2 Warp 3, OS/2 Warp 4, and Motif and tries to
take the best features from those systems. IceWM features multiple
workspaces, opaque move and resize, a taskbar, a window list,
mailbox status, and a digital clock. It is fast and small.

%package config-upstream
Summary:        Window Manager with a Taskbar -- Default configuration
Group:          System/GUI/Other
Conflicts:      icewm-theme-branding
Provides:       icewm-configuration-files = %{version}
BuildArch:      noarch

%description config-upstream
A window manager for the X Window System that can emulate the look
of Windows '95, OS/2 Warp 3, OS/2 Warp 4, and Motif and tries to
take the best features from those systems. IceWM features multiple
workspaces, opaque move and resize, a taskbar, a window list,
mailbox status, and a digital clock. It is fast and small.

Configuration files from upstream provider without suse branding

%package default
Summary:        Window Manager with a Taskbar -- Default Version
Group:          System/GUI/Other
Requires:       adwaita-icon-theme
Requires:       icewm
Requires:       update-alternatives
Provides:       icewm-bin

%description default
A window manager for the X Window System that can emulate the look
of Windows '95, OS/2 Warp 3, OS/2 Warp 4, and Motif and tries to
take the best features from those systems. IceWM features multiple
workspaces, opaque move and resize, a taskbar, a window list,
mailbox status, and a digital clock. It is fast and small.

%package lite
Summary:        Window Manager with a Taskbar -- Lite Version
Group:          System/GUI/Other
Requires:       icewm
Requires:       update-alternatives
Provides:       icewm-bin

%description lite
A window manager for the X Window System that can emulate the look
of Windows '95, OS/2 Warp 3, OS/2 Warp 4, and Motif and tries to
take the best features from those systems. IceWM features multiple
workspaces, opaque move and resize, a taskbar, a window list,
mailbox status, and a digital clock. It is fast and small.

%lang_package

%prep
%setup -q
%patch -P 1 -p1
%patch -P 2 -p1

%build
autoreconf -fi
# Build the Lite version
%configure \
  --disable-silent-rules             \
  --with-cfgdir=%{_sysconfdir}/icewm \
  --enable-i18n                      \
  --disable-nls                      \
  --without-icesound                 \
  --disable-menus-fdo                \
  --disable-fribidi
%make_build
# Grab the lite content.
mkdir lite
for file in %{lites}; do
    mv -f src/$file lite/$file-lite
done
%make_build clean
# Configure for full deployment.
%configure \
  --docdir=%{_docdir}/%{name}        \
  --disable-silent-rules             \
  --with-cfgdir=%{_sysconfdir}/icewm \
  --with-icesound=alsa               \
  --enable-nls                       \
  --enable-corefonts                 \
  --enable-menus-fdo                 \
  --enable-i18n
%make_build
%if !0%{?sle_version}
# Patch generated lib/preferences file.
patch -p1 -i %{PATCH99}
# And use proper branding
wallpaper="openSUSEdefault"
sed -i \
    -e "s:BRANDING_PICTURE:%{_datadir}/wallpapers/$wallpaper/contents/images/1920x1080.png:" \
    src/preferences
%endif

%install
%make_install

# First just remove GNOME WM setter as we don't have GNOME 2 anyway.
rm -f %{buildroot}%{_bindir}/icewm-set-{gnomewm,matewm}

mkdir -p %{buildroot}%{_sysconfdir}/icewm/
for cfgfile in keys menu preferences toolbar winoptions programs; do
    mv -f %{buildroot}%{_datadir}/icewm/$cfgfile \
      %{buildroot}%{_sysconfdir}/icewm/
done
# move preferences to prefoverride to take preference over themes
mv %{buildroot}/%{_sysconfdir}/icewm/preferences \
   %{buildroot}/%{_sysconfdir}/icewm/prefoverride
%find_lang icewm
ln -sf icewm.html %{buildroot}/%{_docdir}/icewm/index.html

mkdir -p %{buildroot}%{_sysconfdir}/alternatives/
for file in %{lites}; do
    mv -f lite/$file-lite %{buildroot}%{_bindir}
    mv -f %{buildroot}%{_bindir}/$file %{buildroot}%{_bindir}/$file-default

    # Dummy.
    touch %{buildroot}%{_sysconfdir}/alternatives/$file
    ln -s %{_sysconfdir}/alternatives/$file %{buildroot}%{_bindir}/$file
done

%suse_update_desktop_file %{buildroot}%{_datadir}/xsessions/icewm-session.desktop

mv -f %{buildroot}%{_datadir}/xsessions/icewm-session.desktop %{buildroot}%{_datadir}/xsessions/icewm.desktop
ln -s icewm.desktop %{buildroot}%{_datadir}/xsessions/icewm-session.desktop

touch %{buildroot}%{_sysconfdir}/alternatives/default-xsession.desktop
ln -s %{_sysconfdir}/alternatives/default-xsession.desktop %{buildroot}%{_datadir}/xsessions/default.desktop

# Link duplicate theme icons to save some space.
%fdupes %{buildroot}%{_datadir}/icewm/themes/

%post
%{_sbindir}/update-alternatives --install %{_datadir}/xsessions/default.desktop \
  default-xsession.desktop %{_datadir}/xsessions/icewm-session.desktop 15

%postun
[ -f %{_datadir}/xsessions/icewm-session.desktop ] || %{_sbindir}/update-alternatives \
  --remove default-xsession.desktop %{_datadir}/xsessions/icewm-session.desktop

%post lite
%{_sbindir}/update-alternatives \
  --install %{_bindir}/icewm       icewm         %{_bindir}/icewm-lite 0       \
  --slave %{_bindir}/icewmhint     icewmhint     %{_bindir}/icewmhint-lite     \
  --slave %{_bindir}/icewmbg       icewmbg       %{_bindir}/icewmbg-lite       \
  --slave %{_bindir}/icesh         icesh         %{_bindir}/icesh-lite         \
  --slave %{_bindir}/icewm-session icewm-session %{_bindir}/icewm-session-lite

%postun lite
if [ $1 -eq 0 ] ; then
    %{_sbindir}/update-alternatives --remove icewm %{_bindir}/icewm-lite
fi

%post default
%{_sbindir}/update-alternatives \
  --install %{_bindir}/icewm       icewm         %{_bindir}/icewm-default 100     \
  --slave %{_bindir}/icewmhint     icewmhint     %{_bindir}/icewmhint-default     \
  --slave %{_bindir}/icewmbg       icewmbg       %{_bindir}/icewmbg-default       \
  --slave %{_bindir}/icesh         icesh         %{_bindir}/icesh-default         \
  --slave %{_bindir}/icewm-session icewm-session %{_bindir}/icewm-session-default

%postun default
if [ $1 -eq 0 ] ; then
    %{_sbindir}/update-alternatives --remove icewm %{_bindir}/icewm-default
fi

%files
%doc %{_docdir}/icewm
%ghost %{_sysconfdir}/alternatives/default-xsession.desktop
%{_datadir}/icewm/
%{_datadir}/xsessions/icewm-session.desktop
%{_datadir}/xsessions/icewm.desktop
%{_datadir}/xsessions/default.desktop
%{_mandir}/man1/*
%{_mandir}/man5/*

%files config-upstream
%dir %{_sysconfdir}/icewm/
%config %{_sysconfdir}/icewm/*

%files lang -f icewm.lang

%files default
%ghost %{_sysconfdir}/alternatives/icewm
%ghost %{_sysconfdir}/alternatives/icewmhint
%ghost %{_sysconfdir}/alternatives/icewmbg
%ghost %{_sysconfdir}/alternatives/icesh
%ghost %{_sysconfdir}/alternatives/icewm-session
%{_bindir}/icewm-default
%{_bindir}/icewmhint-default
%{_bindir}/icewmbg-default
%{_bindir}/icehelp
%{_bindir}/icesh-default
%{_bindir}/icewm-session-default
%{_bindir}/icesound
%{_bindir}/icewm
%{_bindir}/icewmhint
%{_bindir}/icewmbg
%{_bindir}/icesh
%{_bindir}/icewm-session
%{_bindir}/icewm-menu-fdo
%{_bindir}/icewm-menu-xrandr

%files lite
%ghost %{_sysconfdir}/alternatives/icewm
%ghost %{_sysconfdir}/alternatives/icewmhint
%ghost %{_sysconfdir}/alternatives/icewmbg
%ghost %{_sysconfdir}/alternatives/icesh
%ghost %{_sysconfdir}/alternatives/icewm-session
%{_bindir}/icewm-lite
%{_bindir}/icewmhint-lite
%{_bindir}/icewmbg-lite
%{_bindir}/icesh-lite
%{_bindir}/icewm-session-lite
%{_bindir}/icewm
%{_bindir}/icewmhint
%{_bindir}/icewmbg
%{_bindir}/icesh
%{_bindir}/icewm-session

%changelog
* Tue Apr 15 2025 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.7.3:
  * Add ColorQuickSwitchBorder themable preference for issue #736.
  * Make 4 graph widths themable for issue #178.
  * Support grabbing two keys simultaneously by a single keybinding
    definition when both keys are bound to the same keysym.
  * Add support for the _NET_WM_MOVERESIZE_CANCEL protocol option.
  * Add -Await option to icesh to wait for and select new client windows.
  * Unset DESKTOP_AUTOSTART_ID, DESKTOP_STARTUP_ID, XDG_ACTIVATION_TOKEN.
  * Add the "usertime" and "x11time" commands to icesh.
  * Improved loading of fonts in non-Latin environments.
  * Always allow both scrollbars to process the same key event.
  * When a key event is handled, don't propagate it further.
  * Support locales with three letter language codes.
  * Enforce a limit of 8 mouse pointer buttons, as more is impossible.
  * Support keybindings to shifted XF86keysyms like XF86AudioPause.
  * Better guard the integrity of window move/size operations.
  * Increase the maximum number of icewmbg backgrounds to 8000.
  * Let icewmbg also support the AVIF image format.
  * Improve support for properties with COMPOUND_TEXT in icesh.
  * Let icesh accept UTF-8 strings in properties.
* Wed Oct  9 2024 Xiaoguang Wang <xiaoguang.wang@suse.com>
- Add explicit pkgconfig(librsvg-2.0) BuildRequires: Needed support
  svg file (bsc#1222655).
* Mon Jun 17 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.6.0:
  * Support composing characters in the address bar with X input method.
  * Double-click the border to maximize just that side of the window.
  * Repeat the double-click to restore that side. Also for corners.
  * Ignore duplicate requests from GNOME to move or resize a window.
  * Restore the moving of windows by dragging with the right button down.
  * Avoid constructing invalid work areas.
  * Don't dispatch events to destroyed windows.
  * Don't install mouse bindings when the frame is being destroyed.
  * Don't create a Window handle for a destroyed or orphaned window.
* Wed May 22 2024 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.5.0:
  * New -i,--install option installs an icewm-extra theme.
  * Add file argument completion to the address bar.
  * Add "cd" and "pwd" commands to the address bar.
  * Improve tilde expansion on user login names.
  * Document the 22 address bar editing keys.
  * When lowering a frame by KeyWinLower, also lower it in the focus order.
  * Keyboard layout icon names can now be longer than 2 letters.
  * Don't use XSendEvent for internal WM actions, but use XPutBack.
  * When focusing a client, clear urgency and stop flashing.
  * When the frame drops urgency, also update the client.
  * Let "icesh restore" also clear the urgency flag.
  * Several small documentation improvements.
* Thu Apr 18 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Do not recommends icewm-lang: the -lang package has already more
  sophisticated supplements. The various sub-packages require
  icewm, and thus get the supplements satisfied indirectly.
* Tue Apr 16 2024 Bernhard Wiedemann <bwiedemann@suse.com>
- Change DesktopBackgroundImage from .jpg to .png (boo#1222877)
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Thu Dec 28 2023 Sean Lewis <seanlew@opensuse.org>
- Update to 3.4.5:
  * Fix for centering the clock LED digits vertically
  * Fix the KeyWinTile commands for multi-mon setups
  * Fix the workspace buttons for right-to-left languages
* Sat Nov 25 2023 Dirk Müller <dmueller@suse.com>
- update to 3.4.4:
  * Use fcsmart for capturing loadText data.
  * Support TIFF and WEBP in icewmbg.
  * More permissive parsing of a PAM image header in icesh.
  * Remove obsolete winoption examples and add one for
    plank.
  * Use --disable-librsvg instead of --disable-rsvg.
  * Add `supportsFormat` to check for support of additional
    image formats.
  * Support JXL, JP2, RAW, SVG, TGA image formats in
    icewmbg.
  * Test if a color can be considered dark for issue #715.
  * Brighten the color of inactive preview icons for dark
    themes for issue
  * Fix a crash when a ping timeout dialog is destroyed for
    issue #729.
  * Let icewmbg interpret command-line arguments relative
    to the current working directory.
  * Clarify prefoverride and closes #750
  * When mapping a client by PID, search for the best
    match.
  * Don't enforce the use of clang++ in the debug build.
  * Fix ordering in the 4th configuration
  * Fix minor warnings from recent CMake and GCC
  * Translated using Weblate (Portuguese (Brazil))
* Sun Oct 22 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Drop pkgconfig(gdk-pixbuf-xlib-2.0) BuildRequires: No longer
  needed nor used (in our case, we use the new default Imlib2).
- Add explicit pkgconfig(gdk-pixbuf-2.0) BuildRequires: Needed to
  build {_bindir}/icewm-menu-fdo.
* Tue Oct  3 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to version 3.4.3:
  * New preference "TaskBarShowWindowTitles" for icon-only task buttons.
  * New winoption "doNotManage" to workaround bugs in picom for plank.
  * When a battery has no data about full charge, use the capacity.
  * When cascading windows, include the border size in the displacement.
  * Let icewmbg interpret command-line file arguments relative to $PWD.
  * Add a -f,--fork option to icewmbg to detach it from the terminal.
  * Fix the Window List Menu for #144.
  * Fix restoring from fullscreen with F11 in chromium for #141.
  * Support tabs in the Window List Menu.
  * Control the terminal in icewm-menu-fdo by option or environment.
  * Let icewm-menu-fdo use a list of default terminals to choose from.
- Drop unknown config options:
  * --enable-guievents
  * --enable-antialiasing
  * --enable-gradients
  * --enable-shaped-decorations
* Mon Jun  5 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.4.0:
  * Features:
  - Support keybindings to shifted keys for issue #134.
  - Support keybindings to literal Latin-1 characters.
  - Support all UTF-8 code points in keybindings.
  * Fixes:
  - Fix for a map request from an unmanaged client for
    bbidulock/icewm#734.
  - When the keyboard layout changes, reparse the key bindings.
  * Changes:
  - Update the manpage for "icewm-keys".
  - Updated translations.
* Thu May 18 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.3.5:
  * Lookup icons in more context directories for issue ice-wm/icewm#132.
  * An Escape key release event must match the key press event for #726.
  * Report when icon could not be found for issue ice-wm/icewm#133.
  * Use "firefox" instead of "mozilla" as Firefox icon for ice-wm/icewm#132.
  * Rescale workspace buttons when taskbar is rather high.
  * Temporarily hide the taskbar collapse button when collapsing or expanding.
  * Compute the ultimate workspace button height, before creating them.
  * Limit the resource string of an unresponsive client for issue #729.
  * Check for TaskBarDoubleHeight when computing workspace button height.
  * Also focus last window when hiding and Click-to-focus for issue #727.
  * Let icesh exit with zero if the last action was a successful manager
    action.
* Thu May  4 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.3.4:
  * Fix compile error for yximage.cc.
  * Deprecate XRRDisable.
  * Fix corrupted text if built without i18n for issue ice-wm/icewm#131.
  * When internationalization is disabled, unset LIBICONV.
  * Improve the quality of drawing gradients for the Imlib2 renderer.
  * Improve arrow navigation in the system dialog.
  * Let icesh also pick icewm internal and override redirect windows.
  * Improve the quality of drawing gradients for the GdkPixbuf renderer.
  * Cache workspace button backgrounds for faster redrawing.
  * Guard against workspace button gradient being undefined.
  * Cache toolbar button gradients to speedup drawing.  Eliminate half of the
    button drawings on startup.
  * Let icesh report up to 1024 bytes of a property in "prop".
  * Support icesh "focusmodel" for client windows without a WM_HINTS property.
  * When managing a new client, postpone sending a Configure event until the
    final position is known, for issue #720.
* Tue Mar 14 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.3.2:
  * Add yimage_gdk.h.
  * Add "loop" and "pick" commands to icesh. Add "Fullscreen" and "AboveAll"
    layer symbols to icesh.
  * Check for libiconv in configure for OpenBSD.
  * Modify a copy of the WM_CLASS. Prevent messages for loop.
  * Update layer from winoptions when WM_CLASS is changed.
  * Don't set WM_PROTOCOLS on frames.
  * Handle failure of XGetWindowAttributes more graceful in icesh.
  * Faster synchronization.
  * Set a timeout on synchronization. Make window picking more reliable and
    tab-aware.  Add resize handles to "bordered" when client is resizable.
  * Update _NET_WM_ALLOWED_ACTIONS when changing tabs.
  * Let icesh support picking window by frame or title bar.
  * Add "unset" to "icewm-env" to unset environment variables by
    icewm-session.
  * For for "PointerFocusDelay" when mouse crosses different frame border
    subwindows.
  * Check prefs and state before starting delay focus timer.
  * Use "hasBorders" in layoutShape to fix "HideBordersMaximized".
  * When restoring a window, automatically focus it, if nothing has focus.
  * Consider ClickToFocus and StrongPointerFocus when hiding or rolling up.
  * Improve the detection of overlapping windows to the focused window for
    grabbing/releasing the mouse buttons.
  * Cleanup details.
  * Include ClickToFocus in maybeFocus.
  * Document all layer names.
  * Preserve the stacking order for fullscreen windows when Alt+Tabbing for
    issue #611.  When hitting Escape while Alt+Tabbing abandon any
    selection.
  * Fix unpaired parentheses in the manpages.
  * Improve readability of the winoptions manpage.
  * When mapping a new client, check if it overlaps the focus. When taskbar is
    collapsed, don't let it reduce the workarea.
  * Improve more winoption details in the manpages.
* Tue Jan 24 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.3.1:
  * Fully support nanosvg as an alternative to librsvg.
  * Rolled up windows can now be moved vertically with icesh.
  * Fix multi-monitor when primary monitor is right-below of secondary.
  * Don't resize when a client adjusts its WM_NORMAL_HINTS increments.
  * Report the audio interface in the configure summary.
  * Consider that the keyboard may have been changed externally.
  * Increase the timeout for the dynamic menu generator to 2 seconds.
  * Don't reactivate a focused window when RaiseOnClick is guaranteed.
  * Let the winoption "ignorePositionHint" also ignore the USPosition.
  * Fix the "ignoreOverrideRedirect" winoption.
  * Let icesh also spy on RandR monitor configuration events.
* Wed Dec 21 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.3.0:
  * Prevent a derefence of a null-Pixel in xftColor.
  * Add "getClass" and "setClass" commands to icesh.
  * Support tabs in task grouping.
  * Use spaces instead of dots when printing WM_COMMAND.
  * When a focused window hides or rolls up, focus some other window.
  * When looking for a focusable window, avoid rolled up windows.
  * Fix for setting focus on passive motif dialogs
  * Fallback to rolled up windows in the second pass of getLastFocus.
  * Use CurrentTime when setting focus to a passive client in the timeout.
  * On icon not found, report dimensions.
  * Don't refocus a focused window in focusLastWindow.
  * Don't activate an active window when receiving an activation message.
  * Ignore duplicate map requests.
  * Let icesh implicitly select windows at most once.
  * Add support for nanosvg for issue #695.
  * Add preference ToolTipIcon=1 for issue #637.
  * Add nanosvg to .gitignore.
  * Remove unneeded logevent from icesh.
- Remove unknown options from configure
- Rebase icewm-preferences.patch
* Tue Dec  6 2022 Dirk Müller <dmueller@suse.com>
- update to 3.2.3:
  * Only freeze the task pane layout when a button was removed,
  * which fixes the KeySysWorkspaceNext+Prev+Last bug.
  * Ensure that a task button is updated once it is mapped,
  * which prevents stale task button titles.
  * Show a big icon in the tooltip of a toolbar button and the tray.
  * All of the winoptions are now fully tab-aware.
  * More documentation about tabbing in the icewm manpage.
  * Document the "workspace" directory for icons on workspace buttons.
  * Add "loadicon" and "saveicon" commands to icesh.
  * Updated translations: Catalan, Dutch, Slovak, Japanese,
  * Portuguese + Brazil, Macedonian.
* Wed Nov 23 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.2.2:
  + Freeze the task pane layout while Alt is pressed,
  + Only sort Alt+Tab on WM_CLASS when persistent,
  + Also sort Alt+Tab on the 'order' winoption when persistent,
  + Let the Escape key cancel a menu with all its submenu's,
  + Add a menu entry to rename the window title manually,
  + Adapt absolute paths in .desktop files to the installation
    prefix,
  + The sorting of windows in the window list window was improved a
    lot,
  + Restore the named frame tabs when recovering from a crash,
  + Preserve the non-fullscreen non-maximized window geometry
    across restarts,
  + Try harder to avoid a situation where nothing is focused,
  + Update the window list when a tab is moved to its own frame,
  + Make the window list menu actions more tab-savvy.
  + Drop the obsolete LSM file altogether.
- Changes from version 3.2.1:
  + Add QuickSwitchPersistence=0 preference for stateful Alt+Tab.
  + Demarcate workspaces with a horizontal line in Alt+Tab.
  + Fixes for Alt+Tab size calculations.
  + Fix for changing workspace when Alt+Tab is open.
  + Fix for KeySysSwitchClass history.
  + Don't attempt to focus NoInput windows.
  + Ensure that active Alt+Tab item is visible.
  + Also sort Alt+Tab items on WM_CLASS.
  + Fix a compile error for GCC 4.8.5.
  + When moving a tab to a new frame, activate it.
  + Updated translations.
* Thu Nov  3 2022 Victorhck <victorhck@opensuse.org>
- Update to version 3.2.0:
  * Fix for fullscreen wine programs where taskbar would not hide.
  * Ensure KeySysWinNext and KeySysWinPrev always work
    for rolled up windows which use the Globally Active focus model.
  * Give the Alt+Tab a 30 second history.
  * The next Alt+Tab will continue where the previous one left off.
  * Add "tabto" command to icesh move windows as tabs to a new frame.
  * Add "untab" command to icesh to move each tab to its own frame.
  * Add "stacking" and "reverse" commands to icesh.
  * Let icesh check all atoms in the -Property filter.
  * Support edge switching when dragging a window.
  * When switching to a tab with size limitations, adapt the frame geometry.
  * Fix maximize and fullscreen for tabs with different normal sizes.
  * Prevent the flashing when switching tabs.
  * Only popup the grouping menu on a task button on the first button click
    without key modifiers. This makes it easier to immediately select or
    minimize the active application by using the shift or control modifier.
  * Update the title bar shape when changing tabs.
  * Set common properties when adding another tab to a frame.
  * Always update the window list and _NET_CLIENT_LIST when adding more tabs.
  * Add special filtered view and flat rendering options to icewm-menu-fdo.
  * Updated translations.
- from version 3.1.0:
  * Add a winoption "frame" to automatically group application windows
    with the same "frame" value as tabs in a single frame.
  * Show indicators for the presence of tabs on the title bar.
  * Click on the title bar tab indicators to change tabs.
  * Give each tab its own set of winoptions.
  * Fix for merging a transient window as a tab to its owner window.
  * Preserve tray hints across restarts.
  * Preserve tabs across restarts.
  * Improve the Alt+Tab for tabbed frames.
  * When switching tabs, ensure that focus is preserved.
  * Add a MouseWinTabbing preference to merge tabs.
  * Let the window list support tabs.
  * Various improvements to the CMake build.
  * Updated translations.
* Sat Oct  8 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.0.1:
  * Bug fix for Java programs.
  * More elaborate implementation of _NET_REQUEST_FRAME_EXTENTS.
  * Correct keybinding in icewm manpage.
  * Updated translations.
* Tue Oct  4 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.0.0:
  * Add support for tabbed windows (see icewm manpage).
  * Add "ignoreOverrideRedirect" winoption.
  * Hide taskbar with icesh -T hide.
  * Print a message if icewmbg encounters an image loading failure.
  * Add override and focusmodel commands to icesh.
  * Fix setWorkspace issue.
  * Improvements to icewm-menu-xrandr.
  * Clarify the icewmbg manpage about one image per workspace.
  * Updated translations.
* Tue Sep 13 2022 Dirk Müller <dmueller@suse.com>
- update to 2.9.9:
  * Permit percentages to have comma's in icesh.
  * Keep accurate track of window changes in workspace buttons for
    PagerShowPreview.  Only redraw affected workspace buttons, which reduces
    the total number of workspace button redraws, especially for larges
    number of workspace buttons.
  * Add key bindings for single window tiling operations for issues
    bbidulock/icewm#335, ice-wm/icewm#74 and ice-wm/icewm#84.
  * Complete -e option.
  * WindowMaker dock apps are supported.
  * Support more HTML entities in icehelp.
  * Remove dependency on asciidoc and prefer markdown format for the manual.
  * Prevent warnings.
  * Also install markdown.
  * Try srcdir.
  * Cleanup test and prefer markdown manual.
  * Cleanup key grabs.
  * Drop obsolete wmOccupyAll().
  * Accept either markdown or asciidoc to generate manual html with CMake.
  * Add markdown and icesh.
  * Automatically detect and prevent race conditions in icesh relating to
    moving and sizing windows for issue #335. Improve the accuracy of the
    "sizeto" command in icesh for issue #335. Add "extents" command to
    icesh. Add "workarea" command to icesh.
  * Get rid of the frameContext.
  * Prefer findClient in two cases: unmap notify and recv ping.
- spec-cleaner run
* Sat Jul 23 2022 Dirk Müller <dmueller@suse.com>
- update to 2.9.8:
  * Omit trailing dot in CPU temperature and add centigrade symbol for issue
  * If there is no WM active, then a restart will start icewm.
  * Don't create ~/.icewm, unless required to save a file.
  * When showing the desktop, also minimize a focused fullscreen window.
  * Remove unused setTitle from YMsgBox.
  * Add support for COMPOUND_TEXT title names and for non-ascii characters in
  * WM_NAME strings for issue #26.
  * upport COMPOUND_TEXT title names and non-ascii characters in WM_NAME
  * strings in icesh. Limit window dimensions to 32732 in icesh.
  * Prevent warnings.
  * Let TaskBarShowAllWindows influence TaskBarTaskGrouping for issue #560.
  * Improve truncation of titles for TaskBarTaskGrouping in issue #658.
  * Do without pair array.
  * Update the grouping menu when tasks are added or removed.
  * Don't convert XA_STRING names to current locale for issue #26.
  * Update grouping menu when removing a task.
  * Restore 2.5.0 container handling of button presses for issue #649.
  * Don't convert XA_STRING in icesh.
  * Make TaskBarGraphHeight themable for issue #659.
  * Restore prettyClock as false.
  * Preserve errno in testOnce.
  * Clarify which preferences are themable in icewm-preferences(5).
* Fri May 20 2022 QK ZHU <qkzhu@suse.com>
- Rebase patches for version 2.9.7:
  * icewm-susemenu.patch
  * icewm-desktop-nodisplay.patch
  * icewm-preferences.patch
- Update to 2.9.7:
  * Fix for saving keyboard layouts in --rewrite-preferences.
  * Faster and more reliable restart of icewmbg.
  * Add themable preference ColorKeyboardLayoutText.
  * Add KeySysKeyboardNext to switch to next keyboard layout.
  * Document alternative keypad handling in icewm-keys(1).
  * Handle right-to-left languages in icewm-menu-fdo.
  * Add -g,--generic option to icewm-menu-fdo for GenericName in menus.
  * Updated translations: Czech, Danish, Finnish, Turkish, German, French.
- from version 2.9.6:
  * Lower a fullscreen window below the window which is to be activated.
  * Start a new fullscreen client in the fullscreen layer for issue #85.
  * Prioritize the thermal zones when showing CPU temperature.
  * Let CPU graphs share a single timer and adjust to changes to TaskBarCPUSamples.
  * Support workspace names "next" and "prev" in icesh for issue bbidulock/icewm#640.
  * Updated translations: Spanish, German, Italian, Chinese, Portuguese (Brazil).
- from version 2.9.5:
  * Set the window type of desktop icons and of the dockapps container.
  * Make taskbar unhide more reliable.
  * Fix OSS / APM confusion in some translations.
  * Fix for taskbar on icewm restart when there is a fullscreen window.
  * Fix for TaskBarAutoHide and for focusing address bar.
  * Make TaskBarFullscreenAutoShow option more reliable.
  * Remove all of the inefficient management of the fullscreen layer.
  * Fixes to prevent a lockup where no keybinding works,
    when activating a do-not-focus output-only window
    on a workspace where no focusable window exists.
  * When a fullscreen disappears, update the taskbar layer.
  * On startup don't switch workspace to activate a fullscreen window.
  * Updated translations: it, id, pt, pt_BR, de, ar, lt.
- from version 2.9.4:
  * Always keep desktop icons below application windows.
  * Set an icewmbg background color as a pixmap to overcome
    limitations in picom and compton for issue bbidulock/icewm#632.
  * When icewmbg is configured with just a single background image
    or color, then always create a single pixmap in the X11 server as
    a temporary resource and have icewmbg exit to free its memory.
  * Add icesh options +class and +Pid to extend the window selection.
  * Improved workaround for 'feh' desktop backgrounds, where its
    pixmap has been marked persistent, for issue bbidulock/icewm#627.
  * Eliminate flicker when resizing frames which have a shape masked
    border, like CoolSteel and Illuminate-ice by enabling bit gravity.
  * Minimized windows which have both winoptions startMinimized and
    ignoreActivationMessages, require a mouse click to become active.
  * Support focus in subwindows of Globally Active Input applications,
    like games in a Wine virtual desktop for issue #73.
  * Eliminate all flicker when switching between different
    fullscreen windows for issue bbidulock/icewm#630.
  * Always put the active window first in the list of switchable
    windows for issue bbidulock/icewm#631.
  * Updated translation: Portuguese.
- from version 2.9.3:
  * Support Unicode and non-Latin text in input fields and the address bar.
  * Add a Tile submenu to the window menu for issue #74.
  * When icewm starts, force the desktop background to be refreshed,
    for 'feh' background pixmaps in issue bbidulock/icewm#627.
  * Initialize locale specific modifiers with XSetLocaleModifiers.
  * Refresh the task pane background on expose events.
  * Fix for icesh maximize.
  * Fix to eliminate toggling the input focus.
  * Fix for the system tray background for issue bbidulock/icewm#626.
  * Updated translations: Ukrainian, Slovak, Japanese, Catalan, Portuguese.
- from version 2.9.2:
  * Fix for fullscreen wine programs for issue #73.
  * Fix the drawing of LED-clock for themes like "unusualscars".
  * Fix a memory access after free after loading a core font failed.
  * Fix a missing include sys/wait.h for the FreeBSD build.
  * Add support for multiple clocks in different time zones.
  * Internationalize the error messages for the dynamic menu.
  * Internationalize the keyboard tooltip.
- from version 2.9.1:
  * Fix for focusing wine and winecfg for issue bbidulock/icewm#625.
  * Fix the taskbar background for double height taskbar.
  * Swap the columns in the about dialog for right-to-left locales.
  * Replace "sans-serif" with "DejaVu Sans" for Xft fonts,
    because these support a wider range of characters, which
    improves support for languages with non-Latin scripts.
  * Add tabs to CPU multiline status tooltip for two-column display.
  * Fix multiline tooltips for right-to-left locales.
  * Ensure the multiline tab spacing is two character positions.
  * Fix taskbar collapse button for right-to-left locales.
  * Fix workspace pane sizing for right-to-left locales.
  * When the keyboard layout changes due to external reasons
    and the taskbar has the keyboard applet, then reflect
    the new layout in the taskbar applet for issue bbidulock/icewm#622.
  * Make the keyboard applet display all of the output
    of setxkbmap -query in the tooltip for the applet.
  * With the mouse in the keyboard applet, always post the tooltip.
  * Compress a series of XMappingEvents to one keyboard update.
- from version 2.9.0:
  * Improvements to drawing right-to-left text within left-to-right locales.
  * Improvements for right-to-left locales like Arabic and Hebrew.
  * Give icewmbg an error handler to protect against destroyed windows.
  * Updated translations, most notably Ukrainian.
  * Only free cursor attributes when they were allocated.
  * Fix column alignment in menu's for right-to-left languages.
  * Prefer to keep the system menu within the frame when
    opening it from the menu button in the titlebar.
  * Don't repaint the taskbar when it is collapsed.
  * Refresh the taskbar to prevent background artefacts in CoolSteel.
  * Fix the last entry in the themes menu for the default theme.
  * Ignore empty resize events to reduce flickering when resizing in CoolSteel.
  * Only redraw frame borders on the last expose event.
  * Fix the the bottom right hole of a scrolled window list for bbidulock/icewm#620.
  * Add logout icons to Logout submenu for issue #69.
  * Update minimum required cmake version to 3.2.
  * Support right-to-left languages for corefonts when i18n is enabled.
  * When codesets are missing in a fontset, then only search for
    extra fonts in the same font family, and only when i18n is enabled.
  * Detect UTF-8 locale and support multibyte to wide character conversions.
  * Make DejaVu the default backup font family for corefonts.
  * Fix the horizontal scrollbar for the window list window.
  * Improve the ascent/descent detection for font sets.
  * Optimize text length detection for width-limited text fields.
  * Improve the Xft last resort backup font.
  * Improve vertical font positioning for the address bar.
  * Reuse discarded miniicon positions when minimizing to desktop.
  * Flush stdout after printing preferences.
  * Detect Right-To-Left locales Arabic, Hebrew, Farsi, Pashto, Sindhi, Urdu.
  * Improve the handling of font loading failures.
  * Improve the handling of setting "PreferFreetypeFonts" to false.
  * Use the font "10x20" as the last resort font instead of "fixed".
  * Be resilient to font preferences being set to the empty string.
  * Document drag and drop.
  * Add support for edge switching during drag and drop operations.
  * Update icewm.desktop for issue bbidulock/icewm#617.
  * Add a font cache to prevent repeatedly loading the same fonts,
    which also makes icewm a little faster on startup.
  * Don't kill internal windows.
  * Only let a frame retake focus on an ungrab event when the manager still
    believes that frame should have focus. This fixes the flashing of title
    bar buttons when the window list window is popped up.
  * Fix for FreeBSD build.
  * Document the -T switch for taskbar in icesh for issue #18.
- from version 2.8.0
  * Improve the explanation on how to spy on client messages with icesh.
  * When rearranging windows with tile placement or cascade placement, correct for
    the top side vertical offset, in those themes which have a masked top border.
  * Improve the explanation for some of the preferences.
  * Update the winoptions example on DockApps.
  * Guard against a color name being set to the empty string (bbidulock/icewm#614).
  * Improve the performance and scalability of the window list menu.
  * In the window list window group similar application windows together.
  * Add +group and +Class select options to icesh.
  * Improve the filtering on the WM_CLASS property in icesh.
  * Fix the OSS/ALSA defaults in icesound help message (bbidulock/icewm#609).
  * Fix the OSS/ALSA defaults in icesound man page (bbidulock/icewm#608)
  * Only support SVG for icons, not for icewmbg backgrounds.
  * Let icewmbg pixmaps free its associated Image to reduce memory usage.
  * Prevent a potential trailing -I flag in CMake for issue #57.
  * Fix the description for sizeby in the icesh manpage.
  * Fix overflows in battery calculations for issue bbidulock/icewm#607.
  * Update the translations, most notably Brazilian Portuguese.
- from version 2.7.0
  * Increase the maximum value for TaskbarButtonWidthDivisor from 25 to 50.
  * Add a --with-background= build option to set a default background path.
  * Improve the responsiveness of icewmbg when a new image must be scaled.
  * Reduce the memory usage by icewmbg by removing the image cache.
  * Make icewmbg much faster when scanning directories for image files.
  * Improve the reliability of icewm motion compression by also testing
    for subwindow equality.
  * Decrease the number of system calls for path lookups.
  * Guard against array indexing with negative indices.
  * Double the timeout for the dynamic menu generator to 1.4 seconds.
  * Eliminate most of the inefficiences when looking for icon directories.
  * Postpone the loading of cursors, because some cursors are seldomly used.
  * Rewrite the task successor and task predecessor actions to properly
    take into account the separation of TaskBarApp and TaskButton,
    as well as task grouping. This resolves issues #602 and #604.
  * Allow to build icewm using cmake -GNinja (issue #603).
  * Fix building on a case-insensitive file system (issue #601).
- from version 2.6.0:
  * Keep track of changes to modal flag.
  * Optimize raising of modal windows.
  * Fix a memory leak for dynamic menu's.
  * Free start menu and windowlist menu on exit.
  * Fix for browse menu's for root and home in start menu.
  * Eliminate several memory leaks in icon handling.
  * Use absolute paths for the Exec definition in desktop files.
  * Only do a passive grab on buttons which are defined by the ButtonRaiseMask.
  * Guard against buffer overflow when copying the degrees centigrade symbol.
  * When a focused window can't raise, or there is no overlapping window,
    then there shouldn't be a passive button grab by icewm, in order to
    improve menu handling in applications which don't use windows for menu's.
  * Release the passive button grab from a focused window,
    when a button click wouldn't raise it, for improved menu
    handling for applications with internal menu's (CSS drawing).
  * These fix the Debian Bug report with number #989764:
    "icewm: Intermittently unable to select menu items in drop-down menus.",
    which was reported versus IceWM version 2.1.2 on June 12 on:
    https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=989764.
- from version 2.5.0:
  * Fix for a crash when destructing frames with kill message boxes.
  * Clear the UrgencyHint in the WM_HINTS structure to stop the flashing.
  * Collect windows to arrange from layers OnTop, Normal and Below.
  * Add new -unmapped and -viewable filters to icesh.
  * Restore the window selection after an "end" clause in icesh.
  * Add example for constructing dropdown terminals with icesh.
  * Updated 8 translations.
  * Add full support for application modal dialogs.
  * Support WM_TRANSIENT_FOR being equal to the root window, per
    the EWMH standard in section: "Implementing enhanced support
    for application transient windows".
  * Revert "Enforce that focus remains with IceTopWin for issue #593."
  * Support paths with spaces in the rebuild.sh build script.
  * Replace paths with configured directories in generated manpages
    for CMake builds and also fix spaces and double quotes.
  * CMake builds html pages for #50.
- from version 2.4.0:
  * Fix icehelp to ignore a missing file icon.
  * Add support for WindowMaker DockApps to icewm and icesh.
  * Support Ctrl+Mouse buttons to control dockapps.
  * Make icewm resilient against a newly managed client exiting immediately.
  * Ensure that focus remains with IceTopWin when showing desktop for issue #593.
  * Consider AllWorkspaces to be equal to the active workspace in Alt+Tab,
    when QuickSwitchGroupWorkspaces is enabled, for issue #589.
  * Improve recovery from restart failures.
  * Improve icehelp colors.
  * Support searching for keywords in icehelp document with Ctrl+F and F3.
  * Improve centrally placing transient windows over their
    leader window when CenterTransientsOnOwner is enabled.
  * Fix for when CenterLarge is true.
  * Prevent compiler warnings.
  * A dozen translations were updated.
- from version 2.3.4:
  * Add a button for a menu in icehelp.
  * Support anti-aliased fonts in icehelp.
  * Improve accuracy of clicking on links in icehelp.
  * Support reverse video in icehelp.
  * Add more keyboard shortcuts to icehelp.
  * Let icehelp handle scrollbar keys when mouse pointer is inside a scrollbar.
  * Improve vertical alignment of text with different font faces in icehelp.
  * Add a --disable-rsvg option to configure for issue #587.
  * Always rebuild manpages when Makefile changes.
  * Fix for positioning new frames for themes with mask shaped top sides.
  * Fix for snapping frame borders for themes with mask shaped top sides.
  * Generate preferences in sorted order.
  * Better handling of preferences which have null strings by default.
  * Cleaner rewriting of preferences with --rewrite-preferences option.
  * Add a PingTimeout preference for issue #47.
  * When _NET_WM_PING timeouts then request user permission to send
    a terminate signal to the application for issue #47.
  * Fix the exit code of icesh for issue #585.
  * Only use RTTI when debugging for issue #48.
  * Updated translations.
- from version 2.3.3:
  * Document default winoption format .OPTION.
  * Permit scroll wheel to control rolling up or down for issue #584.
  * Add new icewm option --rewrite-preferences to update preferences.
  * Improve documentation for options for Super/Windows key modifiers.
  * Make the QuickSwitch modifiers dependent on the type of QuickSwitch:
    either from the Alt+Tab or from the "switchkey" keyword for issue #583.
  * Don't reorder focus when Alt+Tabbing for issue #579.
  * Defer loading internationalized help text until required.
  * Add support for conditional expressions to icesh.
  * Add a toggle option "^" to the "netState" command for issue #580.
- from version 2.3.2:
  * Document more workspace button features.
  * Improve drawing rectangles with rounded corners.
  * Use reversed active text colors for drawing grouping number.
  * Dissolve the disparity between dragged and non-dragged task buttons.
  * Allow button clicks with some mouse motion between button press and release.
  * Fix for editing workspace name in the workspace button.
  * Repaint workspace button after editing the workspace name.
  * Change the default value for ModSuperIsCtrlAlt from true to false.
  * Support ModSuperIsCtrlAlt in the quick switch for issue #574.
  * Reduce the number of frame updates when changing workspace.
  * Free the memory for the About dialog after it is closed.
  * Prevent a compiler warning.
  * Update Finnish translation.
- from version 2.3.1:
  * Let icewmbg refresh the root background on icewm restart
    to evade a bug in the X server.
  * Prevent compiler warnings about missing overrides.
  * Improve drawing for TaskBarTaskGrouping with preferences.
  * Fix for drawing missing icon in message box.
  * Fix for changing theme via theme menus.
  * Fix for drawing icons in menus.
  * Fix for switchkey.
- from version 2.3.0:
  * Add new preference NetStatusShowOnlyRunning to only
    show running network interfaces by alspitz.
  * Reduce systemcalls as much as possible when updating network status.
  * Only update tooltips when a tooltip window is visible.
  * Postpone creating tooltips.
  * If without system tray, enforce taskbar updateLocation for issue #559.
  * Redraw task button when name changes.
  * Print more details for "all" in "icesh motif".
  * When client loses its X shape then update frame functions, which
    fixes toggling "Use system title bar and borders" in Chrome.
  * Optimize filereader to reduce the number of read system calls.
  * Add new preference TaskBarTaskGrouping to group similar
    applications under a single task button for issue #198.
  * Support immediate toggling of TaskBarTaskGrouping without a restart.
  * Add menu option to icehelp to open current document in a browser.
  * Support switching workspaces via window menu list.
  * Add command "denormal" to icesh for issue #561.
  * Support mouse buttons up to button number 9 for issue #333.
  * Allow to switch workspaces by key in the Alt+Tab QuickSwitch for #563.
  * Improve handling of modifier keys in QuickSwitch.
  * Support arrow keys, Home, End, Delete and Return keys in QuickSwitch.
  * Support keys '1' to '9' to index the QuickSwitch.
  * Prevent closing QuickSwitch window when a button release event occurs.
  * Fixes for QuickSwitch when there is a fullscreen window for issue #558.
  * Add QuickSwitchRaiseCandidate to raise a selected window for issue #564.
  * Don't reorder focus in QuickSwitch when changing workspaces for issue #564.
  * Support rotating mouse wheel buttons in QuickSwitch to scroll over windows.
  * Efficiency improvements to QuickSwitch.
  * When QuickSwitch is up and a new window is created, then add it to the list.
  * Support colored cursors when using libXpm for issue #45.
  * When activating a frame on another workspace, ignore any focus events
    on the root window, for more reliable QuickSwitching to intended window.
  * Updated documentation.
  * Updated translations.
- from version 2.2.1:
  * Fix the CMake build.
  * Draw an icon in each message box popup.
  * Make input field focus tab-traversable when editing preferences.
  * When modifying preferences, only trim input for scalar options.
  * Simplify the icewm manpage.
  * Taskbar may have a non-zero screen due to XineramaPrimaryScreen
    in getNewPos. Only consider workarea when using same screen as
    taskbar, otherwise allow entire desktop for issue bbidulock/icewm#557.
  * Position the move/size-status on the screen of the window.
- from version 2.2.0:
  * Support modifying all icewm preferences directly via a popup.
  * Allow to reset a key or string option in the preferences menu.
  * Show the preference description when modifying a preference.
  * Give each preference option a meaningful description.
  * Drop support for nonICCCMconfigureRequest winoption.
  * Immediately redraw clock after setting default clock format.
  * Add new clock format %%H:%%M to clock menu.
  * Fix cmake test target for issue #41.
  * Improve CMake build speed by building libraries.
  * If an application resizes itself partially outside the work area, then
    move it back inside the work area, if possible, for issue #550.
  * Fix ignoreQuickSwitch winoption for focused windows for issue #552.
  * Support locales in icehelp and icewmhint.
- from version 2.1.2:
  * In icewm-menu-fdo don't abort directory scanning on bad menu items to fix issue #546.
  * Relayout task buttons whenever a task button is removed for issue #548.
  * Add test for XShm extension+pixmaps.
  * Remove the urgent state flag from frame when gaining or losing focus.
  * Add 'urgent' action to icesh to set the urgent flag on a window.
  * Create a Settings submenu to reduce Start menu items for issue #543.
--- ----------------------------------------------------------------
* Tue Jan 26 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.1.1
  * Fix issue #542 for texturing background of task pane.
  * Don't unarm menu popup buttons for issue #527.
  * Provide drawable context when creating pixmap cursors
    with Imlib2 for issue #541.
- from version 2.1.0
  * Remember whether a window is maximized, when going fullscreen, and restore
  * back to maximized, when leaving fullscreen, for issues #538 and #533.
  * Disarm workspace buttons on release of left mouse button for issue #527.
  * Restore icesh setTrayOption and getTrayOption for issue #537.
  * Make support for "_NET_WM_FULLSCREEN_MONITORS" more EWMH conformant.
  * Add "monitors", "frame", "properties" commands to icesh.
  * Make preference FullscreenUseAllMonitors use only all the monitors.
  * Prevent desktop artefacts for non-opaque move and resize to fix issue #540.
  * Option to move the ShowDesktop button to the right side.
  * Alt-F4 in quick-switch closes application window.
- from version 2.0.1
  * Update translations for Japanese, Czech, Dutch, Catalan,
    Portuguese, Slovak, Portuguese (Brazil), Indonesian.
  * Handle horizontal scroll keys in window list window.
  * Search for icewm icon for internal windows.
  * Fix setting option values for issue #535.
  * Allow to set QuickSwitch background opacity for issue #534.
  * Set the window ID in WM_STATE when iconifying to desktop.
  * Reset horizontal scrolling in the window list for Home and End.
  * Add IceVM explanation to README for issue #35.
  * Update the TODO list for icon_pixmap and icon_window fields.
  * Fix spelling of Gerenciador for pt_BR.
* Sun Jan  3 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Add missing imlib2-loaders to Requires
* Sun Dec 20 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 2.0.0
  * Remove support for the old and obsolete _WIN_PROTOCOL properties.
  * Add support for the Imlib2 image rendering engine as an alternative
    for the gdk-pixbuf-xlib rendering engine. The Imlib2 image rendering
    engine is now the default, but this can be set at configure time.
  * Center the window list window if it got offscreen.
  * Fix horizontal scrolling in icehelp.
  * Use _NET_WM_STATE_HIDDEN instead of IconicState for minimize in icesh.
  * Icewm now supports ICCCM icon_pixmap and icon_window.
  * Don't unroll rolled up windows on left button press for issue #525.
  * Fix for drawing title pixmaps when they are gradients for issue #523.
  * Remove unwanted separator in taskbar for empty toolbar for issue #524.
    support BR_Portuguese language in 2 desktop files for issue #522.
  * Add support for WM_HINTS icon_window in MiniIcons.
  * Check if WM_HINTS update actually changes anything.
  * Don't attempt to draw Unicode in non-UTF-8 environment for issue #519
  * Icewm now supports the icon_pixmaps from WM_HINTS to correctly
    show the icon for NEdit, xmgrace, xv, timidity and fontforge.
  * Don't resize when trying to move when dragging at y=0 for issue #520.
  * Report errors if enabled packages are missing for issue #516.
  * Instead of render.h include Xrender.h for dependency checking for issue #516.
  * Fix the positioning of the window list title for non-standard SmallIconSize
    settings for issue #514.
- from version 1.9.2
  * Fix for correctly restoring xterm from fullscreen in issue #28.
  * Prevent inadvertent growing of windows in issue #512.
- from version 1.9.1
  * Fix for NEdit, which delays setting WM_NORMAL_HINTS, to fix issue #510.
  * Fix for changing layers when ABOVE or BELOW bit is set.
  * Use a minimum delay of 10 ms for auto taskbar delays for issue #508.
  * Note in preferences which timing delays are in milliseconds.
  * Ignore applications with _NET_WM_STATE_SKIP_PAGER set in PagerShowPreview.
  * Update XDND protocol version from 3 to 5.
- from version 1.9.0
  * Properly handle name lookup failure for mailboxes for issue #493.
  * Add --valgrind and --catchsegv options to icewm-session to support debugging.
  * Add support for _NET_WM_WINDOW_TYPE to icesh.
  * Always send one synthetic ConfigureNotify on initial window map for issue #492.
  * Remove resize indicators from the frame window when unneeded.
  * Reduce the number of redraws in title bar.
  * Support incomplete _MOTIF_WM_HINTS property for mlterm.
  * Add missing getProtocols to message dialog to fix issue #494.
  * Drop support for ISDN network devices in the network monitor.
  * Update the Catalan, Japanese, Portugeuese, Slovak translations.
  * Update the Czech, Dutch, Indonesian, and Hindi translations.
  * Optimizations to handling of Motif hints to avoid unneeded resizing.
  * Several fixes for correct PagerShowPreview updates for #496.
  * Fix desktop mini icon positioning for fullscreen windows.
  * Don't activate a fullscreen window on startup when it is unmapped.
  * Fixes for TaskBarAutoHide.
  * Improve drawing of ellipsis in titles.
  * Optimize the loading of configuration files.
  * Workaround for non-standard behavior of xnec2c in issue #503.
  * When fullscreen then record resize requests for later restoration.
  * Allow width_inc and height_inc to be zero to disable maximization.
  * Fix handling of WM_CLIENT_LEADER property for Motif applications in #506.
- from version 1.8.3
  * Check if filedescriptor is valid and fix off-by-one allocation error.
  * When icewm starts, reduce the number of workarea updates for taskbar to one.
  * The taskbar only has struts if it is exactly at the top or bottom of the screen.
  * Fix for autohide taskbar not wanting to hide.
  * Support TaskBarAutoHide for TaskBarKeepBelow.
  * Postpone taskbar app status updates until idle, for faster event response.
  * Don't send synthetic ConfigureNotify events for resizing unless required.
  * Do send synthetic ConfigureNotify events for positioning when required.
  * Only send window position updates to the client if it really has moved.
  * Send at most one synthetic ConfigureNotify message per resize.
  * Add proper support for EWMH _NET_RESTACK_WINDOW requests to raise a window.
  * Reflect layer changes in the _NET_WM_STATE ABOVE and BELOW flags.
  * Add WinStateFullscreen to the visible _WIN_STATE bits.
  * Make switch icons opaque for 32-bit visuals.
  * Fix for "icesh -last".
  * Fix issue bbidulock/icewm#491 for F11 fullscreen key on GTK terminals.
  * Support "icesh toggleState Fullscreen"
  * Support icesh "iconic" and "normal" commands for WM_CHANGE_STATE.
  * Use wmHide or wmShow to hide or show the taskbar to fix issue bbidulock/icewm#489.
- from version 1.8.2
  * Fixes for using the proper icon sizes for issue #483.
  * Fixes for reading from pipes in "menuprog" and "menuprogreload" for issue #487.
  * CMake support was extended to the FreeBSD, OpenBSD and Solaris platforms.
  * In "menuprog" and "menuprogreload" do dollar expansion and tilde expansion.
  * New Portuguese (pt) translations.
- from version 1.8.1
  * Fix path_lookup strtok_r for non-Glibc BSD systems for #23.
  * Fix topSideVerticalOffset for fully opaque frame borders for #482.
  * Fix the FreeBSD case where icewm-session is started
  * in the root directory by the display manager.
  * Prevent premature workarea changes when collapsing
  * taskbar to avoid repositioning MiniIcons.
  * Fix the default KeySysArrangeIcons key binding to Alt+Shift+F8.
  * Only define KeySysArrangeIcons if preference MinimizeToDesktop=1.
  * Add KeyWinSmartPlace to preferences.
  * Remove undocumented KeyWinSnapMove.
  * Portability changes for OpenBSD.
  * Prevent cyclic dependencies for transient windows.
  * Also let icesh spy on ClientMessages.
- from version 1.8.0
  * Let workspacebutton use the workspace button fonts when drawing text.
  * Don't switch focus on a FocusOut event on the root window.
  * Prevent the pingponging of focus between windows when one window loses focus.
  * Improved support of applications with transient windows.
  * In the window list window, improve the Show command to
    consider work area and screen boundaries.
  * Give message buttons some padding and a minimum size.
  * Fix the saving of modified options to preferences.
  * Fix opacity in titlebar and task buttons when using gradients.
  * Fix status of logout entry in the logout menu.
  * New theme option MenuButtonIconVertOffset to adjust the position
    of the menu button icon in case ShowMenuButtonIcon=1.
  * Improved ICCCM conformance for restack requests of transient windows.
  * Several improvements to the CrystalBlue theme.
  * Update theme NanoBlue.
  * Change xterm.icon into xterm.XTerm.icon in the default winoptions.
  * More beautiful MiniIcons show just a large shaped icon if MinimizeToDesktop=1.
  * Improved positioning of MiniIcons when the work area grows or shrinks.
  * Enable Arrange Icons in taskbar menu to rearrange all desktop MiniIcons.
  * Add a tooltip to MiniIcons which reflects the window title.
  * Enable dragging MiniIcons with the left mouse button.
  * Ensure icons of irregular sizes are always scaled or loaded.
  * Fix the --logevents option.
  * Update the frame status in the move menu and the layer menu before showing them.
  * Improved Chinese translation by WhiredPlanck.
  * Rename comments from APM monitor to battery monitor by DieSpinne.
  * Efficiency improvements to the relocation of frames when the workarea changes.
  * Better positioning of collapse button to avoid a white line at the bottom of the taskbar.
  * A completely rewritten icon locator by Eduard Bloch which finds many more icons.
  * A new option IconThemes by Eduard Bloch to set your icon theme preferences.
  * Handle more detail in configure request messages.
  * Avoid focusing a random client when a request to stack a client below is received.
  * Update _NET_CLIENT_LIST_STACKING on a configure request to restack a window.
  * Detect when the top side of the title bar border is partially
    transparent for improved positioning.
  * More updated translations.
  * Exclude the collapsed taskbar button from workarea calculations.
  * Update workspace buttons when workspace names change.
  * Show a sticky window just once on all PagerShowPreview workspace buttons.
  * Make button hover work after a click-cancel for issue #448.
  * Fix for correctly computing the X shape mask of shaped titlebars.
  * Fix for updating titlebar shape when title changes.
  * Prevent the delayed focus timer or autoraise timer from interfering
    when a frame is minimized, iconified or rolled up.
  * Don't set the _NET_WM_STATE_FOCUSED flag when mimimized, hidden or rolledup.
  * Set the WM_ICON_SIZE root window property according to theme icon sizes.
  * Add sys/resource.h include for FreeBSD for issue #445.
  * Add definition of ACPIDEV to fix compilation for FreeBSD.
- from version 1.7.0
  * New preference KeyboardLayouts for switching of keyboards layouts.
  * Fix move menu and layer menu for selections in window list window.
  * Don't take away focus from an application when icewm exits.
  * On startup check _NET_ACTIVE_WINDOW and use it to preserve focus over restarts.
  * Set _NET_ACTIVE_WINDOW to None when no window has focus.
  * Better restore focus to window in Above layer when some other window closes.
  * New winoption ignoreActivationMessages to ignore programmatic focus requests.
  * Fix for taskBarWidthPercentage in case screen is not at (0, 0).
  * Use wordexp to avoid a /bin/sh.
  * Fix #21 "Problem with dosbox and re-maximize the screen".
  * Add Maximize Horizontal to window list window.
  * Refresh frames and buttons after screen resize to prevent artefacts.
  * Add detailed tracing of systray activity.
  * Slightly better conformance to XEMBED standard.
  * Reorder systray operations for better test results.
  * Only refocus in setWorkspace if workspace really changes.
  * Reset workspace focused frame if focused frame changes workspace.
  * Fix for negative geometry positions in winoptions.
  * Fix icesh runonce.
  * Fix for icewm --replace.
  * Fix icewm hint processing and make icewmhint geometry work.
  * Let icehelp be quiet when parsing html.
  * Update theme NanoBlue from Nano_Blu-1.3 to evade a bug in Glamor.
- from version 1.6.6
  * Permit deleting entire input line in address bar.
  * Fix for TaskBarShowWindows=0 if TaskBarAutoHide=1 for issue #434.
  * Accept requests for clipboard selection as UTF-8.
  * Request selection as UTF-8 string in addressbar.
  * Add support for setting icewm options in env for icewm-session.
  * New option PagerShowLabels for issue #19.
  * Prevent possible division by zero when calculating battery capacity.
  * Make CPU temperature centered.
  * Fix to make window list icons fit their rows in issue #433.
  * Fix scaled icons in menu for issue #429
  * Fix for systray background filling in issue #430.
  * Fix for CPUStatusShowAcpiTempInGraph=1 in issue #431.
  * Make title buttons behave the same as title bar for Button2.
  * Pass mouse presses on object buttons on to the taskbar for issue #424.
  * Add new -xembed selector for icesh in issue #423.
  * Fix for icesh -window.
  * Add icewm-session --output=FILE option.
  * Repaint frame border immediately for issue #417.
  * Fix TaskBarAutoHide for TaskBarDoubleHeight for issue #415.
  * Port to Solaris.
  * Slightly larger tray app icons.
  * Limit resize band to 3 pixels wide.
  * Better support for RGBA colors.
  * Add support for urxvt -borderless.
  * Fuzzy matching of desktop categories for icewm-menu-fdo.
  * A number of updated translations.
- Add pkgconfig(imlib2) to BuildRequires
- Fix file pattern for manpages in %%files section
- Refresh patches for new version
  - icewm-desktop-nodisplay.patch
  - icewm-preferences.patch
  - icewm-susemenu.patch
* Sat May 16 2020 Namor Barcode <z1trus@gmx.com>
- Update to 1.6.5
  * Fixes and updates for both the configure and the cmake build
  * "icesh last" may only obtain a client list if no previous selection
  * Relinquish the window manager selection when done
  * If "exec xterm" fails then let icewm-session restart icewm
  * Implement all of the functionality of "icesh -X".
  * Document all task button mouse clicks.
  * Optimize the startup of the task bar.
  * New icewm-menu-xrandr "--max" option for menu options selector.
  * Let icewm-menu-xrandr prefer the mode with the highest refresh rate.
  * Document all hidden features of the window list window.
  * Setting winoptions "tray" option non-zero overrules "ignoreTaskBar".
  * Make tray toggle more intuitive by toggling between only two states.
  * When parsing workspace names in icesh also test with spaces trimmed.
  * Filter on property values in icesh and add click and delay to icesh.
  * Filter clients in icesh by EWMH window state.
  * Change the EWMH window state in icesh.
  * Half a dozen fixes and improvements to the window list window.
  * Fix tooltip positioning for multi-monitor when primary screen is right.
  * Add all startup options to generated preferences.
  * Prevent task bar auto hide if address bar is visible for #412.
  * Fix the parsing of the opacity field in rgba colors.
  * Eliminate a large number of superfluous frame border updates.
  Changes in 1.6.4
  * Use "icesh keys" to let icewm reload the keybindings from the "keys" file.
  * Allow mouse pointer buttons to trigger actions from "keys".
  * If a theme cannot be found then fall back on the default theme.
  * Always keep track of the WM_CLIENT_LEADER property.
  * Automatically focus an urgent window in click-to-focus mode,
  * if it has the same leader as the focused window.
  * Set alpha threshold to 10 to completely draw 32-bit icons.
  * Use WM_CLASS to locate an icon if no other source of icon was found.
  * Add tracing of executed programs.
  * Add spy and sizeby commands to icesh.
  * Fix for pagerShowPreview for very wide multi-head desktops.
  * Fix for context menu popup in icehelp.
  * Fix for positioning of splash window on multi-head displays.
  * Fix for positioning of status window on multi-head displays.
  * Fix for positioning of window list window on multi-head displays.
  * Fix for positioning of tooltip windows on multi-head displays.
  * Fix for missed events when monitor changes resolution.
  * Fix for positioning the taskbar when monitor changes resolution.
  * Portability to older systems: only requires libXrandr 1.2 and GCC 4.9.
  * Give icewm a proper implementation of _NET_MOVERESIZE_WINDOW.
  * 10 translations updated.
* Tue Apr 14 2020 Yifan Jiang <yfjiang@suse.com>
- Explicitly require icewm-theme-branding on SLE and Leap.
- Add Conflicts between icewm-config-upstream and icewm-theme-branding
* Mon Mar 16 2020 Yifan Jiang <yfjiang@suse.com>
- Improve build tag consistency between SLE and Leap.
  * Recommend polkit-gnome to both Leap and SLE.
  * Disable icewm-preferences.patch for Leap. The patch makes sense
    to icewm-config-upstream while Leap uses icewm-theme-branding
    the provide the theme.
* Thu Mar  5 2020 Yifan Jiang <yfjiang@suse.com>
- icewm-preferences.patch: Add the adwaita legacy path to the
  IconPath. adwaita-icon-theme has its main icon updated to
  symbolic style, while icewm's style is more suitable for
  legacy-style icons (eg. web-browser). Without the update, current
  icewm can not find default web-browser toolbar icon
  (bsc#1157930).
* Sat Nov 30 2019 Namor Barcode <z1trus@gmx.com>
- Update to 1.6.3
  * Much improved 32-bit icon drawing
  * Add --trace=conf,icon option for path logging
  * Several portability fixes for FreeBSD
  * Update taskbar geometry on screen resize
  * Support PNG format for theme image files
  * Improved support for depcrecated linux.xpm
  * Highlight current workspace on startup
  * Fix for themable cursors
  * Fix for cmake build
  * Fix for rpm build
  * Updated man pages
  * Updated translations
- Changes from 1.5.4
  * Configurable X11 terminal to avoid dependency on xterm
  * Fix support for themable cursors for gdk-pixbuf
  * Fix Xft font corruption in 32-bit alpha mode
  * Fix frame depth for 32-bit apps in 24-bit mode
  * Enable tilde and $HOME expansion for icon paths
  * Restore old behavior of ColorQuickSwitchActive for vertical switching
  * IceSh addWorkspace, prop commands plus -Prop, -Role options
  * IceSh fix getWorkspace for sticky windows, fix getOpacity, improve sync
  * Expand installation prefix in default configuration files and manpages
  * Fix typos in documentation and update Spanish translation
  * Better icewm-session manpage
  * Compile on GCC 9.2 without warning
  * Improve CMake compilation
  * IceWM splash image
  * Silence icehelp
  * Allow a taskbarbg.xpm or taskbarbg.png with transparency for a translucent taskbar
  * Don't use composite on systray when using 24-bit RGB visuals for issue #374
  * Update translations
  * Use lzip instead of xz
  * Add support for 32-bit RGBA visuals if Alpha is enabled.
  * Colors can have a [100] opacity prefix, where 100 is a percentage from 1 to 100.
  * Colors can also be specified in "rgba:" form.
  * Alpha channels in icons are preserved and drawn if Alpha is enabled.
  * Support showing a splash image on startup.
  * Icesh has new commands sizeto, pid, systray, xembed, motif, symbols.
  * Icesh supports filtering on and modifying gravity properties.
  * New winoption "startClose" to immediately close unwanted windows.
  * Several improvements to CMake builds.
  * _NET_SYSTEM_TRAY_ORIENTATION and _NET_SYSTEM_TRAY_VISUAL are now supported.
  * Nearly unlimited number of workspaces.
  * New option TaskBarWorkspacesLimit to limit number of workspaces shown on taskbar.
  * Workspace names can be edited on taskbar.
  * Change default WorkspaceStatusTime to 700 milliseconds.
  * Optimizations of resource usage on startup of icewm.
  * Restore TaskBarFullscreenAutoShow for issue #361.
  * Don't focus frame under mouse for ClickToFocus in issues #355 and #358.
  * Only update if WM_NORMAL_HINTS has really changed for Xephyr in #353.
  * Only update if WIN_HINTS has really changed.
  * Fix icesh -last filter. Fix icesh toggleState for #354.
  * Add another xrandr setup where second screen is primary.
  * Remove support for EsounD.
  * Add many new icesh features.
  * Support opacity in icesh, icewmhint, winoptions.
  * Set window type on all icewm windows.
  * Set WM_CLASS on all icewm windows.
  * Updated translations.
  * More support for clang C++11.
* Tue May 28 2019 Simon Schricker <s.schricker@mailbox.org>
- Update to 1.5.4
  * New get-commands for icesh
  * Support for OnyX theme for yximage
  * Update icewmhint and man pages
  * fix changing workspace names
  * fix NanoBlue icon names
* Wed Apr  3 2019 qzheng <qzheng@suse.com>
- Update to 1.5.3
- Rebase patches
  - icewm-susemenu.patch: rebase "suseprog" function
  - icewm-desktop-nodisplay.patch: rebase, set NoDisplay for
    icewm.desktop
  - icewm-preferences.patch: rebase, only IconPath hunk not in
    upstream now
- Drop patches
  - icewm-mate.patch: upstream no longer uses icewm-menu-gnome2 to
    generate a default menu, the current freedesktop.org approach
    is superior for current distros
  - icewm-use-iproute2-ss-instead-of-netstat.patch:
    was accepted by upstream
* Fri Sep  7 2018 qzheng@suse.com
- Delete icewm.desktop and rename icewm-session.desktop to
  icewm.desktop to fix the upgrade issue ( bsc#1096917 ).
* Tue Mar  6 2018 tiwai@suse.de
- Use asciidoctor instead of asciidoc (bsc#1075764)
* Tue Feb 27 2018 qzheng@suse.com
- Add icewm-use-iproute2-ss-instead-of-netstat.patch:
  Because netstat is not available by default, so call "ss" instead
  of "netstat", and make the "clock" command work on icewm
  ( bsc#1079627 ).
* Wed Jan 17 2018 qzheng@suse.com
- Change the recommend xlockmore to xscreensaver( bsc#1074932 ).
* Thu Dec 21 2017 qkzhu@suse.com
- Drop our distribution's icewm.desktop and use the one provided by
  IceWM upstream
- Add patch icewm-desktop-nodisplay.patch
  Set NoDisplay for upstream's icewm.desktop since it only starts the
  window manager, icewm-session.desktop (the preferred program to
  start the IceWM system) will be displayed in display manager
  (bsc#1072557)
* Fri Dec 15 2017 yfjiang@suse.com
- Make polkit-gnome is recommended in SLE, since SLES requires an
  authentication dialog when being rebooted and shutted-down from
  GUI (bsc#1067788 bsc#1072428)
* Tue Oct 10 2017 tchvatal@suse.com
- Bring back full icewm-preferences.patch from 1.3 series to actually
  work
* Tue Oct 10 2017 tchvatal@suse.com
- Use prefoverride instead of preferences in the sysconfig to make
  sure take priority over theme
- Move programs config option to /etc from /usr/share
* Thu Oct  5 2017 stefan.bruens@rwth-aachen.de
- Partially revert icewm-preferences.patch to previous revision, otherwise
  the icewm default desktop background is used instead of the openSUSE/SLE
  specific one, breaking openQA all over the place
* Sun Sep 24 2017 aavindraa@gmail.com
- Update to 1.4.2
- Rebase patches
  - icewm-susemenu.patch: rebase "suseprog" function
  - icewm-preferences.patch: rebase, only IconPath hunk not in upstream now
  - icewm-mate.patch: rebase several hunks in which context changed
- Drop patches that were accepted upstream
  - icewm-session-desktop.patch
  - icewm-exit-fork.patch
  - icewm-mail.patch
- Swap "sgmltool" for "asciidoc"
* Tue May 23 2017 tchvatal@suse.com
- Fix the updates-alternatives code
* Wed May 17 2017 fvogt@suse.com
- Use update-alternatives to create default.desktop xsession (boo#1030873)
* Wed Feb 22 2017 okurz@suse.com
- Ensure a valid mailbox check tool (bsc#1026134)
  * icewm-mail.patch
  * https://github.com/bbidulock/icewm/pull/108
* Thu Aug 25 2016 fvogt@suse.com
- Add patch icewm-exit-fork.patch to avoid deadlock (bsc#977233)
* Wed Aug 24 2016 tyang@suse.com
- Modify: icewm-preferences.patch
  bnc#977233 modify the command to correct one.
* Thu Jun  2 2016 tchvatal@suse.com
- Use just xlockmore wrt fate#320737
  * icewm-preferences.patch
* Mon Mar 14 2016 tchvatal@suse.com
- Disable image centering, with scaling now working it keeps aspect
  ration with centering enabled:
  * icewm-preferences.patch
* Tue Mar  8 2016 tchvatal@suse.com
- Update prefferences patch to point to correct wallpaper on the disk
  based on openSUSE/SLE branding package
* Tue Mar  8 2016 tchvatal@suse.com
- Add back icewm menu as it is used by us
  * icewm-susemenu.patch
- Add patch to fix icewm session desktop files
  * icewm-session-desktop.patch
* Thu Feb 18 2016 alarrosa@suse.com
- Small fix to continue requiring xterm in distributions that don't
  have xterm-bin (Leap 42.1 and older)
* Wed Feb 17 2016 dimstar@opensuse.org
- Require xterm-bin instead of xterm: only the binary is required.
* Thu Jan 14 2016 petr@cervinka.net
- Version bump to 1.3.12:
  * various bugfixes collected from all upstream vendors
  * added new translations
- Removed upstreamed patches:
  * icewm-toolbar-icons-generic.patch
  * icewm-fix-local-search.patch
* Mon Oct 26 2015 tchvatal@suse.com
- Split out configuration files to allow icewm-theme-branding to
  work
* Mon Oct 26 2015 tchvatal@suse.com
- Simplify reboot/shutdown commands:
  * icewm-preferences.patch
* Mon Oct 26 2015 tchvatal@suse.com
- Enable fribidi support on main package RTL is quite used
* Mon Oct 26 2015 tchvatal@suse.com
- Kill back the mate subpkg as it does not really pose any benefit
  for us. But keep the patch as it should be merged upstream
* Mon Oct 26 2015 tchvatal@suse.com
- Cleanup a bit the update-alternatives syntax
* Sun Oct 25 2015 sor.alexei@meowr.ru
- Add icewm-fix-local-search.patch: make icewm-menu-fdo not to
  search through whole ~/.local/share/ as it can be unexpectedly big.
- Add icewm-toolbar-icons-generic.patch: don't specify paths in
  toolbar icons.
- Require adwaita-icon-theme instead of gnome-icon-theme.
- Append icon search paths to icewm-preferences.patch including
  Adwaita theme.
- Add basic MATE support via icewm-mate.patch and icewm-mate
  subpackage.
- Fix build under openSUSE 13.1.
* Sun Oct 25 2015 tchvatal@suse.com
- Deprecate the gnome subpackage as after investigation we figured
  we can simply use icewm-menu-fdo to generate the taskbar menu
  without any need for gnome2 ties.
- Drop binary icewm-set-gnomewm as the gnome2 is not supported anyway
  and thus gconf settings of its defaults are bit pointless
* Sun Oct 25 2015 tchvatal@suse.com
- Move icesound to default package as alsa is in by default
* Sat Oct 24 2015 tchvatal@suse.com
- Add requires on xterm+alsa-utils that are used in default calls
  of icewm
- For icewm-default add requires on gnome-icon-theme as otherwise
  we would not see icons for most of the things
* Sat Oct 24 2015 tchvatal@suse.com
- Set up icesound to base on alsa only, as OSS and ESD are quite
  not useful nowdays
* Fri Oct 23 2015 zaitor@opensuse.org
- Drop gnome-desktop-devel BuildRequires: That symbol is provided
  by libgnome-desktop-3-devel now, and is not what configure needs,
  nor is looking for. The compat package libgnome-desktop-2-devel
  is the correct one for icewm-gnome, and is already present via
  pkgconfig(gnome-desktop-2.0) BuildRequires.
- Also drop libgnomeui-devel as pkgconfig(libgnomeui-2.0) takes
  care of that.
- Move pkgconfig(gdk-pixbuf-xlib-2.0) BuildRequires: to the with
  gnome section.
* Fri Oct 16 2015 tchvatal@suse.com
- Add back bcond_with gnome conditional as it is redefined on low
  rings
* Fri Oct  9 2015 tchvatal@suse.com
- Sed in lower requirement on gettext to work on Leap and 13.2
* Fri Oct  9 2015 tchvatal@suse.com
- Split lang pkg and properly recommend it
- Install icewm-menu-fdo and manpage
- Properly set docdir
- Add sgmltool to generate html help pages
- Use %%configure macros properly
- Cleanup with spec-cleaner
- Drop bcond for gnome as it is enabled everywhere anyway
- Drop patches that should not be needed after discussion with mmarek:
  * icewm-menu.patch
  * icewm-susemenu.patch
- Peferences file is now in src not in lib so update patch,
  also use systemd to call shutdown and reboot which should be bit more safe
  today:
  * icewm-preferences.patch
* Fri Oct  9 2015 tchvatal@suse.com
- Version bump to 1.3.11:
  * various bugfixes collected from all upstream vendors
- Remove upstreamed patches:
  * icewm-1.2.35-empty-winmenu.patch
  * icewm-1.2.35-override-config.patch
  * icewm-1.2.35-unaligned-access.patch
  * icewm-1.3.6-winoptions.patch
  * icewm-1.3.8-enable-guievents.patch
  * icewm-1.3.8-shutdown-reboot-command.patch
  * icewm-1.3.8.tar.gz
  * icewm-bg-default-at-error.patch
  * icewm-docdir.patch
  * icewm-fix-themes.patch
  * icewm-linking.patch
  * icewm-multiByte.patch
- Refresh patch:
  * icewm-menu.patch
* Mon Jan 12 2015 tyang@suse.com
- Fix the bnc#905159:shutdown and reboot commands not working.
  Change the shutdown and reboot command in preference.
  Add patch: icewm-1.3.8-shutdown-reboot-command.patch
  and updated from upstream:https://github.com/bbidulock/icewm.
* Tue Sep 30 2014 crrodriguez@opensuse.org
- Do not use xorg-x11-devel, select only those packages needed
  for build.
- Build c++ code with fvisibility-inlines-hidden to avoid
  bloating the symbol table.
* Mon Sep 22 2014 fcrozat@suse.com
- Update icewm-preferences.patch with new location of SUSE
  background file.
- Ensure icewm-theme-branding is recommended.
* Tue May 27 2014 tyang@suse.com
- add icewm-1.3.8-shutdown-reboot-command.patch:
  fix the upstream bug of invalid shutdown/reboot command
  change the shutdown/reboot command in preference (bnc#872988)
* Thu Apr 10 2014 tiwai@suse.de
- icewm-bg-default-at-error.patch:
  properly default to the solid color background when the given
  default background pixmap can't be loaded (bnc#872740)
* Mon Mar  3 2014 msrb@suse.com
- icewm-fix-themes.patch
  * Workaround for bnc#856931.
* Wed Jan 22 2014 tyang@suse.com
- update version to 1.3.8
- remove patches:icewm-gcc47.patch,icewm-x11.patch
- add two new patches:icewm-1.3.8-enable-guievents.patch,icewm-susemenu.patch
  for new fate #313170
* Wed Jan  8 2014 coolo@suse.com
- merge icewm-lite into icewm.spec using update-alternatives
* Thu Mar 28 2013 mmeister@suse.com
- Added url as source.
  Please see http://en.opensuse.org/SourceUrls
* Tue May 22 2012 idonmez@suse.com
- Fix build with gcc 4.7
- Fix build with new X11 headers
* Tue Dec 20 2011 coolo@suse.com
- add autoconf as buildrequire to avoid implicit dependency
* Mon Aug 29 2011 crrodriguez@opensuse.org
- Must link with -lfontconfig too, fix build.
* Tue Apr 26 2011 mmarek@novell.com
- Change the command to apply icewm-preferences.patch to make
  automatic checks happy.
* Mon Mar 21 2011 mmarek@novell.com
- Fix shutdown and reboot (bnc#681126).
* Mon Mar 21 2011 mmarek@novell.com
- Update to 1.3.7:
  * battery status as graphics not text (Alexander Drozdov)
  * 'icewm-set-gnomewm' script to set GNOME window manager to icewm
  * bugfixes
* Wed Sep  8 2010 vuntz@opensuse.org
- Change old-style BuildRequires to pkgconfig() style
  BuildRequires:
  + old-style: gnome-desktop-devel, libgnomeui-devel.
  + new-style: gdk-pixbuf-xlib-2.0, gnome-desktop-2.0,
    libgnomeui-2.0.
- This will make it easier to switch to GNOME 3 libraries.
* Tue Jan 26 2010 mmarek@suse.cz
- fix applying of custom window options.
* Tue Jan 26 2010 mmarek@suse.cz
- update to 1.3.6
  * XRANDR support
  * uses gdk-pixbuf instead of imlib
* Mon Sep  7 2009 mmarek@suse.cz
- icewm-1.2.38pre1-bad-delete.patch: fix for bnc#525804
* Wed Apr 29 2009 mmarek@suse.cz
- updated to 1.2.38pre1
  * bugfixes
* Sun Feb 22 2009 vuntz@novell.com
- Add icewm-1.2.36-gnome-compilation.patch to fix build. The patch
  should probably be sent upstream.
- Add libgnomeui-devel BuildRequires for the patch.
* Fri Oct 24 2008 mmarek@suse.de
- updated to 1.2.36 final
  * add option TaskBarFullscreenAutoShow (default = 1)
  * fixes --with-line build
* Mon Sep 29 2008 mmarek@suse.cz
- fixed unaligned access in XChangeProperly()
* Thu Sep 11 2008 mmarek@suse.cz
- updated to 1.2.36pre2
  * add support for sysfs interface (instead of proc) for battery
    status (initial code by Santiago Garcia Mantinan)
  * bugfixes & translation updates
* Fri Jul 18 2008 mmarek@suse.cz
- also fix session locking (use xscreensaver or xlock) (bnc#406156)
* Fri Jul 18 2008 mmarek@suse.cz
- make shutdown and reboot work out of the box (bnc#406156)
* Fri Mar  7 2008 mmarek@suse.cz
- don't popup empty window menu
* Fri Feb 29 2008 mmarek@suse.cz
- fixed centering of dialogs (bnc#359529)
* Tue Jan 29 2008 mmarek@suse.cz
- make icewm --config=file work
  (override-config.patch)
* Mon Jan 28 2008 mmarek@suse.cz
- updated to 1.2.35
  * Application tray bug fixes
  * Add encoding/language to about dialog
  * fix gmplayer switching to fullscreen
  * popup dialog focus fixes
  * fix screen change with xrandr 1.2
  * build fixes (Bert Wesarg)
  * fix FocusOnRaise
  * tray fixes
  * fix taskbar popup in fullscreen mode
- don't install genpref (only needed at build time)
- fixed build for older distributions in X11:windowmanagers
- use %%%%suse_update_desktop_file
* Mon Aug 13 2007 mmarek@suse.cz
- updated to 1.2.32 [#299583]
  * auto-hide like taskbar activation in full screen mode added
  * missing ShowSettingsMenu and ShowFocusModeMenu
    settings (Evgenii Terechkov)
  * binding to raise window with mouse
    (MouseWinRaise=Ctrl+Alt+Mouse1)  (Thomas Holder)
  * translation updates (cs, ru, zh_CN, zh_TW)
  * bugfixes
- link duplicate theme icons
* Sat Mar  3 2007 aj@suse.de
- /usr/share/xsessions/ is part of filesystems now.
* Wed Jan 24 2007 mmarek@suse.cz
- fixed strict aliasing warning
* Fri Jan 12 2007 mmarek@suse.cz
- fix last change (Start -> Help didn't work)
  (icewm-docdir.patch)
* Thu Jan 11 2007 mmarek@suse.cz
- updated to 1.2.30
  + battery status cleanups
  + new option BatteryPollingPeriod (default 10 seconds)
  + moved Themes selection to Settings menu
  + added Settings -> Focus menu (config saved to
    ~/.icewm/focus_mode as FocusMode=1,2 or 0)
  + new setting MapInactiveOnTop (default 1)
  + new setting RequestFocusOnAppRaise (when FocusOnAppRaise=0)
  + altgr_binding_support by Jörg Sommer
  + Apple PMU support by Jörg Sommer
  + start menu pixmap now named: taskbar/start.xpm
  + try to mouse focus only when mouse actually moves to another
    window
  + prevent focusing taskbar with mouse focus
  + use locale strings in 'icewm-menu-gnome2'
  + also search for .png icons when only basename is specified
    (Manuel Carrasco)
  + change mouse cursor when dragging the taskbar (Manuel Carrasco)
  + icewmtray: catch HUP signal to reload theme and other fixes
    (Manuel Carrasco)
  + new preferences option: WinMenuItems (default=rmsnxfhualyticw)
    (Manuel Carrasco/Marko Macek)
  + added 'Look=flat' (oscarello)
  + added TaskbarButtonWidthDivisor (lysanderslair)
  + bugfixes and translation updates
- spec file cleanup
  + reduced buildrequires
  + icewm-gnome is only an add-on to icewm-default, one spec file
    less
  + use /usr/share/doc/packages/icewm (not icewm-%%%%version)
  + fixed default wallpaper location
* Tue May 16 2006 pnemec@suse.cz
- updated to 1.2.26
  many minor fix
  some translation fix
  strict-aliasing patch  is in upstream now
* Tue Feb 14 2006 mmarek@suse.cz
- fixed strict-aliasing patch once more
  [#150786]
- use make -j
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 20 2006 tiwai@suse.de
- fixed strict-aliasing patch (#143861)
* Mon Jan  2 2006 pnemec@suse.cz
- fixed wrong name of Norwegian messages
- removed X11R6 prefix
* Wed Dec 21 2005 ro@suse.de
- added locale dirs to filelist
* Mon Nov 28 2005 pnemec@suse.cz
- fixed strict aliasing errors ( -strict-aliasing.patch)
* Mon Nov 14 2005 pnemec@suse.cz
- updated to 1.2.23
* Fri Aug 12 2005 ltinkl@suse.cz
- fix icewm.desktop problems (#94917 and #100494)
* Tue Jul 26 2005 ltinkl@suse.cz
- update to 1.2.22
* Wed Jun 29 2005 ltinkl@suse.cz
- update to 1.2.21
- adjust patches
* Mon May 23 2005 ltinkl@suse.cz
- update to 1.2.20
* Wed Feb 23 2005 meissner@suse.de
- fixed 0->NULL in Xft call.
* Thu Jan  6 2005 ltinkl@suse.cz
- update to 1.2.19
- fix missing docu (#47112)
* Tue Nov  2 2004 ltinkl@suse.cz
- updated to 1.2.16
* Thu Aug 12 2004 ltinkl@suse.cz
- update to 1.2.15
* Fri Mar 12 2004 ltinkl@suse.cz
- make the XDG menu work
- use the default SUSE wallpaper
* Fri Feb  6 2004 ltinkl@suse.cz
- support for xdg menu
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Wed Oct 15 2003 ltinkl@suse.cz
- updated to 1.2.13
* Fri Jul 11 2003 nadvornik@suse.cz
- updated to 1.2.9
- built with gnome2
* Fri Jun 13 2003 kukuk@suse.de
- use find_lang macro
* Thu May 29 2003 nadvornik@suse.cz
- installed genpref
* Mon May  5 2003 mfabian@suse.de
- remove "fontconfig fontconfig-devel" from neededforbuild and
  use x-devel-packages instead of xf86
- use "-*-" instead of "-xftdummy-" as the foundry for the
  default fonts when using Xft because the latest fontconfig
  now actually uses the foundry and inserting an dummy value
  doesn't work anymore.
* Fri Apr 25 2003 lmfabian@suse.de
- update to 1.2.7
- add "fontconfig fontconfig-devel" to neededforbuild
- icewm-always-use-xft.patch: if we have Xft2, don't disable Xft
  when no RENDER is found.
- remove icewm-menu-translations.tar.bz2: the language specific
  "preferences" files did only set different fontsets, which is
  not necessary anymore when Xft2 is used with generic aliases
  like "sans" and "monospace" as the default settings. The same
  default font settings should work for all languages.
  The other files in icewm-menu-translations.tar.bz2 didn't
  contain any important language specific differences either.
- fix icewm-LANG.menu.patch: look for the most specific extensions
  first: e.g. first try "menu.ja_JP.UTF-8", then try "menu.ja_JP",
  finally try "menu.ja". The current patch did it in the opposite
  order, making it impossible to have different files for
  ja_JP.eucJP and ja_JP.UTF-8.
* Mon Mar 10 2003 nadvornik@suse.cz
- added Requires: icewm to icewm-gnome [#24936]
* Mon Feb 17 2003 nadvornik@suse.cz
- use g++ for compilation and linking
* Fri Feb 14 2003 nadvornik@suse.cz
- updated to 1.2.6
* Thu Nov 28 2002 nadvornik@suse.cz
- fixed to compile with new gcc
* Tue Oct 22 2002 nadvornik@suse.cz
- set multiByte to true by default [#20656]
* Fri Sep 27 2002 ro@suse.de
- Added alsa alsa-devel to neededforbuild (esound)
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Fri Jul 26 2002 nadvornik@suse.cz
- updated to 1.2.0
* Wed Jun 26 2002 nadvornik@suse.cz
- updated to 1.2.0pre3: many bugs fixed
* Tue May 28 2002 meissner@suse.de
- link with $(CXX), not with gcc, or it will miss C++ symbols.
* Mon Apr 22 2002 nadvornik@suse.cz
- fixed to compile
* Tue Apr  2 2002 nadvornik@suse.cz
- used suse_update_config
* Wed Mar 13 2002 nadvornik@suse.cz
- added dir /etc/X11/icewm to filelist
* Tue Mar 12 2002 nadvornik@suse.cz
- fixed Super key handling [bug #14734]
* Sun Feb 10 2002 ro@suse.de
- tar option for bz2 is now "j"
* Thu Jan 31 2002 ro@suse.de
- changed neededforbuild <libpng> to <libpng-devel-packages>
* Tue Oct 23 2001 nadvornik@suse.cz
- update to 1.0.9
  - icon tray
  - mouse wheel support for menus
  - additional key bindings
  - improved edge switching
  - many bugfixes
* Mon Oct 15 2001 nadvornik@suse.cz
- fixed path to help files [bug #11793]
* Mon Aug 13 2001 nadvornik@suse.cz
- compiled with g++ (now compiles on axp)
* Fri Aug 10 2001 nadvornik@suse.cz
- update to 1.0.8
- created packages icewm-gnome, icewm-default,
  icewm-lite [bug #5692]
* Mon May  7 2001 mfabian@suse.de
- bzip2 sources
* Wed Mar 21 2001 ro@suse.de
- added esound-devel to neededforbuild
* Tue Feb 20 2001 uli@suse.de
- fixed for new glibc
* Fri Jan 26 2001 mfabian@suse.de
- fixed broken German and Russian translations
  they were broken because they had been saved in iso-2022.
- added Japanese and German translations for the menus.
* Fri Jan 26 2001 violiet@suse.de
- added patch to enable NLS (Native Language Support).
  This patch adds --enable-nls to configure, adds bindtextdomain()
  and textdomain() calls, replaces regular strings with strings
  translatable by gettext and adds po files for de, ja, ko, ru,
  and zh_TW.Big5.
- added patch to load translated menus from files with a locale
  suffix, e.g. menu.ko, menu.ja ...
- added Korean translations for menus
* Tue Nov 28 2000 grimmer@suse.de
- removed icewm-themes-0.9.42.tar.gz from package
- moved system-wide configuration files to /etc/X11/icewm
  for better FHS compliance
- removed symlink needed for the old susewm
* Wed Nov  1 2000 egger@suse.de
- Updated specfile to new long packagenames.
- Reworked specfile.
- Probably needs some more work; I'm taking care of that.
* Wed Jun 28 2000 grimmer@suse.de
- Update to 1.0.4
* Tue Jun  6 2000 uli@suse.de
- moved docs to %%{_docdir}
* Mon Mar 27 2000 grimmer@suse.de
- update to 1.0.3
* Thu Mar 16 2000 grimmer@suse.de
- update to 1.0.2
- added BuildRoot
* Wed Jan 26 2000 grimmer@suse.de
- new version (1.0.1)
- specfile cleanups (version-macro, added more docu)
- activated imlib- and i18n-support
* Mon Jan  3 2000 grimmer@suse.de
- new version (1.0.0)
* Wed Dec 22 1999 grimmer@suse.de
- new version (0.9.55)
- specfile cleanups
* Tue Dec  7 1999 grimmer@suse.de
- new version (0.9.53) - bugfixes, new features
* Wed Nov 17 1999 grimmer@suse.de
- new version (0.9.50)
- added GNOME-support
* Sun Oct 10 1999 grimmer@suse.de
- new version (0.9.49) - bugfixes, new features
* Mon Sep 20 1999 ro@suse.de
- added Provides windowmanager
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Wed Aug 25 1999 grimmer@suse.de
- new version (0.9.48) - bugfixes, new features
* Wed Aug 18 1999 bs@suse.de
- added Check.
* Wed Aug 18 1999 grimmer@suse.de
- new version (0.9.46) - bugfixes
* Wed Jun 16 1999 grimmer@suse.de
- new version (0.9.42) - bugfixes
- added themes package for enhanced pleasure
* Fri May 28 1999 grimmer@suse.de
- new version (0.9.41) - bugfixes
- minor specfile-updates (now uses configure instead of config)
- removed patch, since configure now handles the path names
- added genpref binary to RPM (generates sample config file)
* Tue Apr 13 1999 grimmer@suse.de
- new version (0.9.37) - bugfixes, new features
* Tue Mar 16 1999 grimmer@suse.de
- created symlink to menu (needed for susewm)
* Thu Feb 18 1999 grimmer@suse.de
- new version (0.9.33) - bugfixes
* Wed Jan 27 1999 grimmer@suse.de
- new version (0.9.30) - bugfixes, new features
* Sun Nov 15 1998 grimmer@suse.de
- new version (0.9.17) - bugfixes
- added HTML documentation
- specfile fixes
* Fri Jul  3 1998 maddin@suse.de
- first S.u.S.E. Version 0.9.8
